==> nsc-2.0.3-121-GA.update.tgz: var/webconfig/FS_modules/application/libraries/fs_certificate_module_class.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
/**
 * FS Certificate Module Class
 * @author Shaunt Libarian
 */
require_once ('application/helpers/safe_helper.php');
safe_require_class('safe_service_class');
safe_module_require_class('fs', 'application');
safe_module_require_class('fs', 'ca_certificate_config');

class Fs_certificate_rehash_class extends Safe_configuration_user_class
{
    public function __construct($dir)
    {
        parent::__construct($dir, 'c_rehash');
    }
    public function run($node)
    {
        return $node->execute('sudo /usr/bin/c_rehash ' . $this->file_name());
    }
}


class Fs_certificate_module_class extends Fs_module_class
{
    private $_obj_base_path = '';
    private $_ca = array();
    public function __construct($fs_app)
    {
        parent::__construct($fs_app, "certificate");
        $this->_obj_base_path = $fs_app->object_name().'/profile';
    }
    public function configure()
    {
        // Set the module description
        $this->set_description("Certificate");
        // Register objects
        $this->register_aggregate_object('ca',
            array(
                'name' => 'CA',
                'dynamic' => false,
                'base_path' => $this->_obj_base_path . '/ca',
                'class' => 'Fs_ca_certificate_config_class ',
            )
        );
        return parent::configure();
    }

    public function generate_config(&$config_manager)
    {
        if(!$this->_generate_config($config_manager)) return false;
        return parent::generate_config($config_manager);
    }
    const CA_STORE = 'ssl/CA_store/';
    const CA_PROFILES = 'ssl/profiles/';
    private function _generate_config(&$config_manager)
    {
        $this->_serialize_ca($config_manager, $this->cas());
        $this->_serialize_server($config_manager, $this->cas(), $this->fs_app()->sip_profiles());

        return true;
    }
    /**
     * Handles serialization of CA Certificates
     * @param object  $config_manager 
     * @param object  $ca_certificates
     * @return boolean
     */
    protected function _serialize_ca(&$config_manager, $ca_certificates)
    {
        // Remove directories
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_STORE, '', Safe_configuration_class::CFG_DELETE, Safe_configuration_class::CFG_DIR));
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_STORE, '', Safe_configuration_class::CFG_CREATE, Safe_configuration_class::CFG_DIR));
        foreach ($ca_certificates as $cert) {
            $ca = $cert->name();
            //Place certificate in CA_store
            $file = Fs_certificate_module_class::CA_STORE . $cert->name();
            $cert_content = $cert->get_data_value('certificate-file-contents', false);
            $config_manager->add_config(
                new Safe_configuration_class(
                    $file, 
                    base64_decode($cert_content) , 
                    Safe_configuration_class::CFG_UPDATE, 
                    Safe_configuration_class::CFG_FILE));
        }
    }

    /**
     * Handles serialization of SIP profile Certificates
     * @param object  $config_manager 
     * @param object  $ca_certificates
     * @param object  $sip_profiles   
     * @return boolean
     */
    protected function _serialize_server(&$config_manager, $ca_certificates, $sip_profiles)
    {
        // Remove directories
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_PROFILES, '', Safe_configuration_class::CFG_DELETE, Safe_configuration_class::CFG_DIR));
        // make sure SSL directories exists
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_PROFILES, '', Safe_configuration_class::CFG_CREATE, Safe_configuration_class::CFG_DIR));
        $cfg_dir = $config_manager->directory('configuration') . '/';

        // Check SIP profile uses certficate ?
        foreach ($sip_profiles as $sip_cfg) {
            $ua_cert_name = "";
            $ua_cert_content = "";
            if($sip_cfg->get_certificate_info($ua_cert_name, $ua_cert_content)){
                // Create sip profile ssl dir
                $directory = 'ssl/profiles/' . $sip_cfg->name();
                $config_manager->add_config(new Safe_configuration_class($directory, '', Safe_configuration_class::CFG_CREATE, Safe_configuration_class::CFG_DIR));
                // Serialize the profile certificate
                $file = 'ssl/profiles/' . $sip_cfg->name() . '/agent.pem';
                $config_manager->add_config(new Safe_configuration_class($file, base64_decode($ua_cert_content) , Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_FILE));
             
                // Any CA cert ?
                foreach ($ca_certificates as $cert) {
                    $ca = $cert->name();
                    //Update the SIP Profile with the symbolic link on CA cert
                    $file_link['original'] = $cfg_dir . Fs_certificate_module_class::CA_STORE . $ca;
                    $file_link['target'] = $cfg_dir . Fs_certificate_module_class::CA_PROFILES . $sip_cfg->name() . '/' . $ca;
                    $config_manager->add_config(new Safe_configuration_class($file_link, '', Safe_configuration_class::CFG_LINK, Safe_configuration_class::CFG_FILE));

                }
                //run c_rehash
                $dir = $cfg_dir . Fs_certificate_module_class::CA_PROFILES . $sip_cfg->name();
                $config_manager->add_config(new Fs_certificate_rehash_class($dir));
            }
        }

        return true;
    }
    /**
     * Returns all the dialplans
     */
    public function cas()
    {
        $this->_cas = $this->get_aggregate_objects('ca');
        return $this->_cas;
    }
}
?>

==> nsc-2.0.8-140-GA.update.tgz: var/webconfig/FS_modules/application/libraries/fs_certificate_module_class.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
/**
 * FS Certificate Module Class
 * @author Shaunt Libarian
 */
require_once ('application/helpers/safe_helper.php');
safe_require_class('safe_service_class');
safe_module_require_class('fs', 'application');
safe_module_require_class('fs', 'ca_certificate_config');

class Fs_certificate_rehash_class extends Safe_configuration_user_class
{
    public function __construct($dir)
    {
        parent::__construct($dir, 'c_rehash');
    }
    public function run($node)
    {
        return $node->execute('sudo /usr/bin/c_rehash ' . $this->file_name());
    }
}


class Fs_certificate_module_class extends Fs_module_class
{
    private $_obj_base_path = '';
    private $_ca = array();
    public function __construct($fs_app)
    {
        parent::__construct($fs_app, "certificate");
        $this->_obj_base_path = $fs_app->object_name().'/profile';
    }
    public function configure()
    {
        // Set the module description
        $this->set_description("Certificate");
        // Register objects
        $this->register_aggregate_object('ca',
            array(
                'name' => 'CA',
                'dynamic' => true,
                'base_path' => $this->_obj_base_path . '/ca',
                'class' => 'Fs_ca_certificate_config_class ',
            )
        );
        return parent::configure();
    }

    public function reload_generate_config(&$config_manager, $obj_type=null)
    {
        if(!$this->_generate_config($config_manager)) return false;
        return parent::reload_generate_config($config_manager, $obj_type);
    }
    public function reload_clear_modified($obj_type=null)
    {
        // the hard way :)
        Safe_object_serializer_class::get_serializer()->clear_modified($this->_obj_base_path, true);
    }

    public function support_reload(&$need_reload = NULL)
    {
        foreach($this->fs_app()->sip_profiles() as $profile){
            if(
               /* $profile->get_certificate_info($i, $j) 
               && */
                $profile->is_modified()){
                $need_reload = true;
                break;
            }
        }
        return true;
    }
    public function is_configuration_modified($include_childs = true)
    {
        // Check if a SIP module is modified
        foreach($this->fs_app()->sip_profiles() as $profile){
            if(
                /* $profile->get_certificate_info($i, $j) && */
                $profile->is_modified()){
                return true;
            }
        }
        return parent::is_configuration_modified($include_childs);
    }

    public function generate_config(&$config_manager)
    {
        if(!$this->_generate_config($config_manager)) return false;
        return parent::generate_config($config_manager);
    }
    const CA_STORE = 'ssl/CA_store/';
    const CA_PROFILES = 'ssl/profiles/';
    private function _generate_config(&$config_manager)
    {
        $this->_serialize_ca($config_manager, $this->cas());
        $this->_serialize_server($config_manager, $this->cas(), $this->fs_app()->sip_profiles());

        return true;
    }
    /**
     * Handles serialization of CA Certificates
     * @param object  $config_manager 
     * @param object  $ca_certificates
     * @return boolean
     */
    protected function _serialize_ca(&$config_manager, $ca_certificates)
    {
        // Remove directories
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_STORE, '', Safe_configuration_class::CFG_DELETE, Safe_configuration_class::CFG_DIR));
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_STORE, '', Safe_configuration_class::CFG_CREATE, Safe_configuration_class::CFG_DIR));
        foreach ($ca_certificates as $cert) {
            $ca = $cert->name();
            //Place certificate in CA_store
            $file = Fs_certificate_module_class::CA_STORE . $cert->name();
            $cert_content = $cert->get_data_value('certificate-file-contents', false);
            $config_manager->add_config(
                new Safe_configuration_class(
                    $file, 
                    base64_decode($cert_content) , 
                    Safe_configuration_class::CFG_UPDATE, 
                    Safe_configuration_class::CFG_FILE));
        }
    }

    /**
     * Handles serialization of SIP profile Certificates
     * @param object  $config_manager 
     * @param object  $ca_certificates
     * @param object  $sip_profiles   
     * @return boolean
     */
    protected function _serialize_server(&$config_manager, $ca_certificates, $sip_profiles)
    {
        // Remove directories
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_PROFILES, '', Safe_configuration_class::CFG_DELETE, Safe_configuration_class::CFG_DIR));
        // make sure SSL directories exists
        $config_manager->add_config(new Safe_configuration_class(Fs_certificate_module_class::CA_PROFILES, '', Safe_configuration_class::CFG_CREATE, Safe_configuration_class::CFG_DIR));
        $cfg_dir = $config_manager->directory('configuration') . '/';

        // Check SIP profile uses certficate ?
        foreach ($sip_profiles as $sip_cfg) {
            $ua_cert_name = "";
            $ua_cert_content = "";
            if($sip_cfg->get_certificate_info($ua_cert_name, $ua_cert_content)){
                // Create sip profile ssl dir
                $directory = 'ssl/profiles/' . $sip_cfg->name();
                $config_manager->add_config(new Safe_configuration_class($directory, '', Safe_configuration_class::CFG_CREATE, Safe_configuration_class::CFG_DIR));
                // Serialize the profile certificate
                $file = 'ssl/profiles/' . $sip_cfg->name() . '/agent.pem';
                $config_manager->add_config(new Safe_configuration_class($file, base64_decode($ua_cert_content) , Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_FILE));
             
                // Any CA cert ?
                foreach ($ca_certificates as $cert) {
                    $ca = $cert->name();
                    //Update the SIP Profile with the symbolic link on CA cert
                    $file_link['original'] = $cfg_dir . Fs_certificate_module_class::CA_STORE . $ca;
                    $file_link['target'] = $cfg_dir . Fs_certificate_module_class::CA_PROFILES . $sip_cfg->name() . '/' . $ca;
                    $config_manager->add_config(new Safe_configuration_class($file_link, '', Safe_configuration_class::CFG_LINK, Safe_configuration_class::CFG_FILE));

                }
                //run c_rehash
                $dir = $cfg_dir . Fs_certificate_module_class::CA_PROFILES . $sip_cfg->name();
                $config_manager->add_config(new Fs_certificate_rehash_class($dir));
            }
        }

        return true;
    }
    /**
     * Returns all the dialplans
     */
    public function cas()
    {
        $this->_cas = $this->get_aggregate_objects('ca');
        return $this->_cas;
    }
}
?>
